@@ -4,7 +4,7 @@
     const_err,
     dead_code,
     deprecated,
-    duplicate_associated_type_bindings,
+    deprecated_in_future,
     duplicate_macro_exports,
     ellipsis_inclusive_range_patterns,
     exceeding_bitshifts,
@@ -30,11 +30,13 @@
     non_shorthand_field_patterns,
     non_snake_case,
     non_upper_case_globals,
+    order_dependent_trait_objects,
     overflowing_literals,
     parenthesized_params_in_types_and_modules,
     path_statements,
     patterns_in_fns_without_body,
     plugin_as_library,
+    private_doc_tests,
     private_in_public,
     proc_macro_derive_resolution_fallback,
     pub_use_of_private_extern_crate,
